@@ -46,6 +46,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC"), silent=TRUE, df=NULL){
     if(!is.data.frame(ourData)){
         ourData <- as.data.frame(ourData);
     }
+    # Select IC
     ic <- ic[1];
     if(ic=="AIC"){
         IC <- AIC;
@@ -116,8 +117,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC"), silent=TRUE, df=NULL){
         else{
             bestIC <- currentIC;
             bestFormula <- testFormula;
-            ourData <- cbind(ourData,residuals(testModel));
-            colnames(ourData)[ncol(ourData)] <- paste0(newElement," resid");
+            ourData[,ncol(ourData)] <- residuals(testModel);
         }
     }
 
